/*************************************************  Common Functions Header  **************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	Copyright 2014, Red Rapids, Inc.

*************************************************  Common Functions Header  **************************************************/

#ifndef _COMMON_FUNCTIONS_H_
#define _COMMON_FUNCTIONS_H_

#if defined(__cplusplus)
	extern "C" {
#endif

// Structure to store time of day (TOD) clock settings.
typedef struct
{
	unsigned long TODSeconds;
	unsigned long ClockFrequency;
	unsigned long TSFCode;
	unsigned long TSICode;
} s_TODSettings;

// Structure to store the LED source configuration settings.
typedef struct
{
	unsigned long LEDA[10];
	unsigned long LEDB[4];
} s_LEDSource;

// Structure to store GPIO settings.
typedef struct
{
	unsigned long Direction[6];
	unsigned long OutputValue[6];
	unsigned long DebounceEnable[6];
	unsigned long Disconnect;
	unsigned long TriggerDebounceEnable;
} s_GPIOSettings;

// Structure to store the results returned by a error status query to the device.
// Structure to store interrupt mask settings assigned to each type of error.
typedef struct
{
	unsigned long Bar[4];
	unsigned long Clock[8];
} s_ErrorStatus;

// Structure to store the results returned by an interrupt status query to the device.
typedef struct
{
	unsigned long Channel[8];
	unsigned long Error;
} s_GlobalStatus;

// Structure to store temperature results measured on the device.
typedef struct
{
	double Sensor[5];
	double Vcc;
} s_Temperature;

// Structure to store power results measured on the device.
typedef struct
{
	double Supply1[3];
	double Supply2[3];
	double Supply3[3];
} s_Power;

// Prototypes for each of the common functions in alphabetic order.
unsigned long BusClose(s_Adapter *p_HW);
unsigned long BusOpen(s_Adapter *p_HW);
unsigned long ChannelCount(s_Adapter *p_HW, size_t RxTxSelect);
unsigned long ClockInit(s_Adapter *p_HW);
unsigned long ClockStatus(s_Adapter *p_HW, unsigned long ChipSelect);
unsigned long ErrorMask(s_Adapter *p_HW, s_ErrorStatus ErrorIntMask);
unsigned long FirmwareRevision(s_Adapter *p_HW);
unsigned long GetErrorStatus(s_Adapter *p_HW, s_ErrorStatus *p_ErrorStatus);
unsigned long GetGlobalStatus(s_Adapter *p_HW, s_GlobalStatus *p_GlobalStatus);
double GetPower(s_Adapter *p_HW, s_Power *p_Power);
unsigned long GetTemperature(s_Adapter *p_HW, s_Temperature *p_Temperature);
unsigned long GetTODSeconds(s_Adapter *p_HW);
unsigned long GlobalSync(s_Adapter *p_HW);
unsigned long InterruptMask(s_Adapter *p_HW, unsigned long GlobalIntMask);
unsigned long LED(s_Adapter *p_HW, s_LEDSource LEDSource);
unsigned long LoadGPIOSettings(s_Adapter *p_HW, s_GPIOSettings GPIO);
unsigned long LoadTODSettings(s_Adapter *p_HW, s_TODSettings TODClock);
unsigned long MicrosecondTimer(unsigned long Time);
unsigned long ModelNumber(s_Adapter *p_HW);
unsigned long Read(s_Adapter *p_HW, unsigned long Bar, unsigned long Off, unsigned long long *p_Value);
unsigned long Serial(s_Adapter *p_HW, unsigned long BusSelect, unsigned long MultiFunction, unsigned long Instruction, size_t AddressSize, unsigned long Data, size_t DataSize, unsigned long *p_ReadValue);
unsigned long SoftwareReset(s_Adapter *p_HW);
unsigned long SoftwareTrigger(s_Adapter *p_HW);
unsigned long Write(s_Adapter *p_HW, unsigned long Bar, unsigned long Off, unsigned long long Value);

#ifdef __cplusplus
}
#endif

#endif
